use test0::add_1;
use test0::sub_1;
use test0::M;
use test0::N;

pub fn add_2()
{
    unsafe {
        N += 2;
        println!("my_project N: {}",N);
    }
}

pub fn add_twice()
{
    println!("--my_project::add_twice()--");
    test0::add_1();
    test0::add_1();
    println!("----");
}



